#! /bin/bash
# icewm_update_menu.sh
# version 0.1.2
# GPL v3

# i18n stuff
. gettext.sh

TEXTDOMAIN=icewm_update_menu.sh
export TEXTDOMAIN
TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAINDIR


MENU=$HOME/.icewm/menu

function get_app {
	if [ -f $1/$2.desktop ]
	  then
	    NAME=$(cat $1/$2.desktop | grep "^Name=" | cut -b 6-)
	    ICON=$(cat $1/$2.desktop | grep "^Icon=" | cut -b 6-)
	    #X added in case variable is empty
	    if [ "X$ICON" = "X" ]; then 
		ICON=$2
	    fi
	    EXEC=$(cat $1/$2.desktop | grep "^Exec=" | cut -b 6- | sed s/\%u//g | sed s/\%U//g | sed s/\%f//g | sed s/\%F//g)
	    echo "  " prog \"$NAME\" $ICON $EXEC >> $MENU
	fi
}

function print_applist {
	PATH_TO_APPS=$1
	shift
	apps=( "${@}" )
	for index in ${apps[@]}
		do
		get_app $PATH_TO_APPS $index
	done
}

function first_app {
	NAME=$(cat $1/$2.desktop | grep "^Name=" | cut -b 6-)
	ICON=$(cat $1/$2.desktop | grep "^Icon=" | cut -b 6-)
	EXEC=$(cat $1/$2.desktop | grep "^Exec=" | cut -b 6-)
	echo prog \"$NAME\" $ICON $EXEC > $MENU
}

# Path to desktop files
APPS="/usr/share/applications"
APPS_KDE="/usr/share/applications/kde4"

# Menu names for i18n
MENU_AUDIO_MAIN="`eval_gettext \"Audio\"`"
MENU_AUDIO_CONNECTION="`eval_gettext \"Connection\"`"
MENU_AUDIO_EDITION="`eval_gettext \"Edition\"`"
MENU_AUDIO_MASTERING="`eval_gettext \"Mastering\"`"
MENU_AUDIO_MIXERS="`eval_gettext \"Mixers\"`"
MENU_AUDIO_PLAYERS="`eval_gettext \"Players\"`"
MENU_AUDIO_RECORDING="`eval_gettext \"Recording\"`"
MENU_AUDIO_SYNTHESIS="`eval_gettext \"Synthesis\"`"
MENU_AUDIO_DSP="`eval_gettext \"DSP\"`"
MENU_AUDIO_TOOLS="`eval_gettext \"Tools\"`"
MENU_AUDIO_TUNERS="`eval_gettext \"Tuning\"`"
MENU_EDUCATION="`eval_gettext \"Education\"`"
MENU_GRAPHICS="`eval_gettext \"Graphics\"`"
MENU_HELP="`eval_gettext \"Help\"`"
MENU_MIDI_MAIN="`eval_gettext \"MIDI\"`"
MENU_MIDI_SEQUENCERS="`eval_gettext \"Sequencing\"`"
MENU_MIDI_SOFTSYNTHS="`eval_gettext \"SoftSynths\"`"
MENU_MIDI_MUSICSHEET="`eval_gettext \"Music Sheet\"`"
MENU_MIDI_METRONOME="`eval_gettext \"Metronome\"`"
MENU_NET="`eval_gettext \"Internet\"`"
MENU_OFFICE="`eval_gettext \"Office\"`"
MENU_VIDEO="`eval_gettext \"Video\"`"
MENU_TOOLS="`eval_gettext \"Tools\"`"
MENU_SYSTEM="`eval_gettext \"System\"`"

# Other translatable strings
NORMAL_SESSION="`eval_gettext \"Normal session\"`"


# Applications
AUDIO_CONNECT=( aconnectgui jackeq patchage qjackctl )
AUDIO_DSP=( calf creox freqtweak guitarix jack-rack Jc_Gui rakarrack )
AUDIO_EDITORS=( audacity freecycle gnusound gwc mhwaveedit mp3splt-gtk rezound soundconverter sweep wavbreaker )
AUDIO_MASTERING=( jamin )
AUDIO_MIXERS=( alsamixergui aumix-gtk echomixer envy24_control ffado.org-ffadomixer gnome-alsamixer hdspconf hdspmixer rmedigicontrol xfce4-mixer )
AUDIO_PLAYERS=( alsaplayer audacious2 djplay )
AUDIO_PLAYERS_KDE=( amarok )
AUDIO_RECORDERS=( ardour audacity jokosher traverso )
AUDIO_SYNTHESIS=( Annotator NetworkEditor Prototyper puredata )
AUDIO_TOOLS=( extace jaaa jackeq jkmeter meterbridge )
AUDIO_TUNERS=( fmit lingot )
EDUCATION=( ScoreReadingTrainer solfege )
GRAPHICS=( blender-windowed gimp gpicview gtkam inkscape openoffice.org-draw xsane )
GRAPHICS_KDE=( ksnapshot )
MIDI_METRONOME=( gtick gtklick )
MIDI_MUSICSHEET=( canorus denemo mscore noteedit nted rosegarden songwrite tuxguitar )
MIDI_MUSICSHEET_KDE=( frescobaldi )
MIDI_SEQUENCERS=( freewheeling hydrogen kluppe milkytracker muse qtractor rosegarden seq24 sooperlooper )
MIDI_SOFTSYNTHS=( ams amsynth hexter horgand lv2rack nekobee phasex qsynth specimen yoshimi zynaddsubfx zynjacku )
MIDI_TOOLS=( vkeybd vmpk specimen )
NET_NAVIGATORS=( iceweasel )
NET_NAVIGATORS_KDE=( konqbrowser KMail )
NET_CHAT=( amsn pidgin xchat )
NET_TOOLS=( filezilla gftp )
NET_TOOLS_KDE=( kget )
VIDEO=( camorama cheese Kino pitivi xine xjadeo LiVES )
OFFICE=( abiword gnumeric leafpad openoffice.org-base openoffice.org-calc openoffice.org-impress openoffice.org-math openoffice.org-writer )
TOOLS=( pcmanfm xarchiver )
TOOLS_KDE=( dolphin k3b )
SYSTEM=( lxappearance lxinput lxrandr firestarter synaptic )
SYSTEM_KDE=( knetworkmanager )
HELP_KDE=( Help )

# First applications
first_app $APPS "lxterminal"
echo separator >> $MENU
get_app $APPS "gnome-alsamixer"
echo separator >> $MENU
get_app $APPS "qjackctl"
echo separator >> $MENU

# Menu Rosegarden
echo menu \"Rosegarden\" folder \{ >> $MENU
echo "  " prog \"README demos Rosegarden\" rosegarden icehelp /usr/share/musix_demos/estudios/LEEME_Rosegarden.html >> $MENU
echo "  " separator >> $MENU
echo "  " prog \"Rosegarden \($NORMAL_SESSION\)\" rosegarden rosegarden >> $MENU
echo "  " prog \"Rosegarden+Audio\" rosegarden musixstarter /usr/share/musix_demos/starters/rg+audio.starter >> $MENU 
# prog "Rosegarden+Qsynth-General-MIDI+ALSA" qsynth rosegarden+qsynth8mb_alsa.sh
echo "  " prog \"Rosegarden+Qsynth\" qjackctl musixstarter /usr/share/musix_demos/starters/rg+qsynth.starter >> $MENU
echo "  " prog \"Rosegarden+Qsynth \(Piano-mgg\)\" qsynth musixstarter /usr/share/musix_demos/starters/rg+piano-mgg.starter >> $MENU
echo "  " prog \"Rosegarden+SoundBlaster \(Piano-mgg\)\" vkeybd musixstarter /usr/share/musix_demos/starters/rg+piano-mgg+sb.starter >> $MENU
echo "  " prog \"Rosegarden+DSSI \(Hexter\)\" rosegarden musixstarter /usr/share/musix_demos/starters/rg+dssi.starter >> $MENU
echo "  " prog \"Rosegarden+DSSI \(Sineshaper\)\" rosegarden musixstarter /usr/share/musix_demos/starters/rg+sineshaper.starter >> $MENU
echo "  " prog \"Rosegarden+DSSI \(Soundfonts\)\" rosegarden musixstarter /usr/share/musix_demos/starters/rg+dssi-sf.starter >> $MENU
echo "  " prog \"Rosegarden+Hydrogen\" hydrogen musixstarter /usr/share/musix_demos/starters/rg+hydrogen.starter >> $MENU
# prog "Rosegarden+Qsynth+Piano-mgg" qsynth rosegarden+qsynth+piano-mgg_alsa.sh
# prog "Rosegarden+swami+piano-mgg_sb.sh" rosegarden rosegarden+swami+piano-mgg_sb.sh
# prog "Rosegarden+timidity_alsa11025" rosegarden rosegarden+timidity_alsa11.sh
# prog "Rosegarden+timidity_alsa22050" rosegarden rosegarden+timidity_alsa22.sh
# prog "Rosegarden+timidity_alsa44100" rosegarden rosegarden+timidity_alsa.sh
echo "  " prog \"Rosegarden+Timidity\" qjackctl musixstarter /usr/share/musix_demos/starters/rg+timidity.starter >> $MENU
echo "  " separator >> $MENU
echo "  " prog \"Demo Odisea\" zynaddsubfx musixstarter /usr/share/musix_demos/starters/rg+zyn.starter >> $MENU
echo "  " prog \"Demo Tecno\" zynaddsubfx musixstarter /usr/share/musix_demos/starters/rg+zyn-tecno.starter >> $MENU
echo "  " prog \"Demo Zapada Lenta demo\" zynaddsubfx musixstarter /usr/share/musix_demos/starters/rg+zyn-zapada-lenta.starter >> $MENU
echo "  " prog \"Demo Ok, I lied\" zynaddsubfx musixstarter /usr/share/musix_demos/starters/rg+zyn-ok-i-lied.starter >> $MENU
echo \} >> $MENU
echo separator >> $MENU

# Menu NET
echo menu \"$MENU_NET\" folder \{ >> $MENU
print_applist $APPS ${NET_NAVIGATORS[@]}
print_applist $APPS_KDE ${NET_NAVIGATORS_KDE[@]}
echo "  " separator >> $MENU
print_applist $APPS ${NET_CHAT[@]}
echo "  " separator >> $MENU
print_applist $APPS ${NET_TOOLS[@]}
print_applist $APPS_KDE ${NET_TOOLS_KDE[@]}
echo \} >> $MENU

# Menu GRAPHICS
echo menu \"$MENU_GRAPHICS\" folder \{ >> $MENU
print_applist $APPS ${GRAPHICS[@]}
print_applist $APPS_KDE ${GRAPHICS_KDE[@]}
echo \} >> $MENU

# Menu OFFICE
echo menu \"$MENU_OFFICE\" folder \{ >> $MENU
print_applist $APPS ${OFFICE[@]}
echo \} >> $MENU

# Menu AUDIO
echo menu \"$MENU_AUDIO_MAIN\" folder \{ >> $MENU
echo "  " menu \"$MENU_AUDIO_CONNECTION\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_CONNECT[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_RECORDING\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_RECORDERS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_EDITION\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_EDITORS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_DSP\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_DSP[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_MASTERING\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_MASTERING[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_MIXERS\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_MIXERS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_PLAYERS\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_PLAYERS[@]}
print_applist $APPS_KDE ${AUDIO_PLAYERS_KDE[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_SYNTHESIS\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_SYNTHESIS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_TOOLS\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_TOOLS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_AUDIO_TUNERS\" folder \{ >> $MENU
print_applist $APPS ${AUDIO_TUNERS[@]}
echo "  " \} >> $MENU
echo \} >> $MENU

# Menu MIDI
echo menu \"$MENU_MIDI_MAIN\" folder \{ >> $MENU
echo "  " menu \"$MENU_MIDI_SEQUENCERS\" folder \{ >> $MENU
print_applist $APPS ${MIDI_SEQUENCERS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_MIDI_SOFTSYNTHS\" folder \{ >> $MENU
print_applist $APPS ${MIDI_SOFTSYNTHS[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_MIDI_MUSICSHEET\" folder \{ >> $MENU
print_applist $APPS ${MIDI_MUSICSHEET[@]}
print_applist $APPS_KDE ${MIDI_MUSICSHEET_KDE[@]}
echo "  " \} >> $MENU
echo "  " menu \"$MENU_MIDI_METRONOME\" folder \{ >> $MENU
print_applist $APPS ${MIDI_METRONOME[@]}
echo "  " \} >> $MENU
print_applist $APPS ${MIDI_TOOLS[@]}
echo \} >> $MENU

# Menu EDUCATION
echo menu \"$MENU_EDUCATION\" folder \{ >> $MENU
print_applist $APPS ${EDUCATION[@]}
echo \} >> $MENU

# Menu VIDEO
echo menu \"$MENU_VIDEO\" folder \{ >> $MENU
print_applist $APPS ${VIDEO[@]}
echo \} >> $MENU

# Menu TOOLS
echo menu \"$MENU_TOOLS\" folder \{ >> $MENU
print_applist $APPS ${TOOLS[@]}
print_applist $APPS_KDE ${TOOLS_KDE[@]}
echo \} >> $MENU

# Menu SYSTEM
echo menu \"$MENU_SYSTEM\" folder \{ >> $MENU
print_applist $APPS ${SYSTEM[@]}
print_applist $APPS_KDE ${SYSTEM_KDE[@]}
echo \} >> $MENU

# Menu HELP
echo menu \"$MENU_HELP\" folder \{ >> $MENU
print_applist $APPS_KDE ${HELP_KDE[@]}
echo \} >> $MENU
